@@ -2,7 +2,7 @@
 # This file is part of pygal
 #
 # A python svg graph plotting library
-# Copyright © 2012 Kozea
+# Copyright © 2012-2013 Kozea
 #
 # This library is free software: you can redistribute it and/or modify it under
 # the terms of the GNU Lesser General Public License as published by the Free
@@ -55,20 +55,25 @@ class Ghost(object):
         config(**kwargs)
         self.config = config
         self.raw_series = []
+        self.raw_series2 = []
 
-    def add(self, title, values):
+    def add(self, title, values, secondary=False):
         """Add a serie to this graph"""
         if not hasattr(values, '__iter__') and not isinstance(values, dict):
             values = [values]
-        self.raw_series.append((title, values))
+        if secondary:
+            self.raw_series2.append((title, values))
+        else:
+            self.raw_series.append((title, values))
 
-    def make_series(self):
-        return prepare_values(self.raw_series, self.config, self.cls)
+    def make_series(self, series):
+        return prepare_values(series, self.config, self.cls)
 
     def make_instance(self):
         self.config(**self.__dict__)
-        series = self.make_series()
-        self._last__inst = self.cls(self.config, series)
+        series = self.make_series(self.raw_series)
+        secondary_series = self.make_series(self.raw_series2)
+        self._last__inst = self.cls(self.config, series, secondary_series)
         return self._last__inst
 
     # Rendering
@@ -98,12 +103,12 @@ class Ghost(object):
         with io.open(filename, 'w', encoding='utf-8') as f:
             f.write(self.render(is_unicode=True))
 
-    def render_to_png(self, filename):
+    def render_to_png(self, filename=None, dpi=72):
         """Render the graph, convert it to png and write it to filename"""
         import cairosvg
-        from io import BytesIO
-        fakefile = BytesIO()
-        fakefile.write(self.render())
-        fakefile.seek(0)
-        cairosvg.surface.PNGSurface.convert(
-            file_obj=fakefile, write_to=filename)
+        return cairosvg.svg2png(
+            bytestring=self.render(), write_to=filename, dpi=dpi)
+
+    def _repr_png_(self):
+        """Display png in IPython notebook"""
+        return self.render_to_png()
