@@ -2,7 +2,7 @@
 # This file is part of pygal
 #
 # A python svg graph plotting library
-# Copyright © 2012 Kozea
+# Copyright © 2012-2013 Kozea
 #
 # This library is free software: you can redistribute it and/or modify it under
 # the terms of the GNU Lesser General Public License as published by the Free
@@ -36,7 +36,7 @@ class Bar(Graph):
         self._x_ranges = None
         super(Bar, self).__init__(*args, **kwargs)
 
-    def _bar(self, parent, x, y, index, i, zero, shift=True):
+    def _bar(self, parent, x, y, index, i, zero, shift=True, secondary=False):
         width = (self.view.x(1) - self.view.x(0)) / self._len
         x, y = self.view((x, y))
         series_margin = width * self._series_margin
@@ -57,10 +57,17 @@ class Bar(Graph):
         transpose = swap if self.horizontal else ident
         return transpose((x + width / 2, y + height / 2))
 
-    def bar(self, serie_node, serie, index):
+    def bar(self, serie_node, serie, index, rescale=False):
         """Draw a bar graph for a serie"""
         bars = self.svg.node(serie_node['plot'], class_="bars")
-        for i, (x, y) in enumerate(serie.points):
+        if rescale and self.secondary_series:
+            points = [
+                (x, self._scale_diff + (y - self._scale_min_2nd) * self._scale)
+                for x, y in serie.points]
+        else:
+            points = serie.points
+
+        for i, (x, y) in enumerate(points):
             if None in (x, y) or (self.logarithmic and y <= 0):
                 continue
             metadata = serie.metadata.get(i)
@@ -72,7 +79,7 @@ class Bar(Graph):
             val = self._format(serie.values[i])
 
             x_center, y_center = self._bar(
-                bar, x, y, index, i, self.zero)
+                bar, x, y, index, i, self.zero, secondary=rescale)
             self._tooltip_data(
                 bar, val, x_center, y_center, classes="centered")
             self._static_value(serie_node, val, x_center, y_center)
@@ -93,10 +100,38 @@ class Bar(Graph):
             self._box.ymin, self._box.ymax, self.logarithmic, self.order_min
         ) if not self.y_labels else map(float, self.y_labels)
 
-        self._x_labels = self.x_labels and zip(self.x_labels, [
-            (i + .5) / self._len for i in range(self._len)])
-        self._y_labels = zip(map(self._format, y_pos), y_pos)
+        self._x_labels = self.x_labels and list(zip(self.x_labels, [
+            (i + .5) / self._len for i in range(self._len)]))
+        self._y_labels = list(zip(map(self._format, y_pos), y_pos))
+
+    def _compute_secondary(self):
+        if self.secondary_series:
+            y_pos = zip(*self._y_labels)[1]
+            ymin = self._secondary_min
+            ymax = self._secondary_max
+
+            min_0_ratio = (self.zero - self._box.ymin) / self._box.height
+            max_0_ratio = (self._box.ymax - self.zero) / self._box.height
+
+            new_ymax = (self.zero - ymin) * (1 / min_0_ratio - 1)
+            new_ymin = -(ymax - self.zero) * (1 / max_0_ratio - 1)
+            if ymax > self._box.ymax:
+                ymin = new_ymin
+            else:
+                ymax = new_ymax
+
+            left_range = abs(self._box.ymax - self._box.ymin)
+            right_range = abs(ymax - ymin)
+            self._scale = left_range / right_range
+            self._scale_diff = self._box.ymin
+            self._scale_min_2nd = ymin
+            self._y_2nd_labels = [
+                (self._format(self._box.xmin + y * right_range / left_range),
+                 y)
+                for y in y_pos]
 
     def _plot(self):
         for index, serie in enumerate(self.series):
             self.bar(self._serie(index), serie, index)
+        for index, serie in enumerate(self.secondary_series, len(self.series)):
+            self.bar(self._serie(index), serie, index, True)
