@@ -2,7 +2,7 @@
 # This file is part of pygal
 #
 # A python svg graph plotting library
-# Copyright © 2012 Kozea
+# Copyright © 2012-2013 Kozea
 #
 # This library is free software: you can redistribute it and/or modify it under
 # the terms of the GNU Lesser General Public License as published by the Free
@@ -39,7 +39,7 @@ class Dot(Graph):
 
     def dot(self, serie_node, serie, r_max):
         """Draw a dot line"""
-        view_values = map(self.view, serie.points)
+        view_values = list(map(self.view, serie.points))
         for i, value in safe_enumerate(serie.values):
             x, y = view_values[i]
             size = r_max * value
@@ -69,8 +69,9 @@ class Dot(Graph):
                 (x_pos[i], y_pos[j])
                 for i in range(x_len)]
 
-        self._x_labels = self.x_labels and zip(self.x_labels, x_pos)
-        self._y_labels = zip(self.y_labels or cut(self.series, 'title'), y_pos)
+        self._x_labels = self.x_labels and list(zip(self.x_labels, x_pos))
+        self._y_labels = list(zip(
+            self.y_labels or cut(self.series, 'title'), y_pos))
 
     def _plot(self):
         r_max = min(
