@@ -2,7 +2,7 @@
 # This file is part of pygal
 #
 # A python svg graph plotting library
-# Copyright © 2012 Kozea
+# Copyright © 2012-2013 Kozea
 #
 # This library is free software: you can redistribute it and/or modify it under
 # the terms of the GNU Lesser General Public License as published by the Free
@@ -25,12 +25,15 @@ from __future__ import division
 from pygal.interpolate import interpolation
 from pygal.graph.base import BaseGraph
 from pygal.view import View, LogView, XYLogView
-from pygal.util import is_major, truncate, reverse_text_len
-from math import isnan, pi, sqrt, ceil
+from pygal.util import (
+    is_major, truncate, reverse_text_len, get_texts_box, cut, rad)
+from math import isnan, pi, sqrt, ceil, cos
+from itertools import repeat, chain
 
 
 class Graph(BaseGraph):
     """Graph super class containing generic common functions"""
+    _dual = False
 
     def _decorate(self):
         """Draw all decorations"""
@@ -48,7 +51,7 @@ class Graph(BaseGraph):
     def _set_view(self):
         """Assign a view to current graph"""
         if self.logarithmic:
-            if self.__class__.__name__ == 'XY':
+            if self._dual:
                 view_class = XYLogView
             else:
                 view_class = LogView
@@ -128,18 +131,38 @@ class Graph(BaseGraph):
             self.svg.node(axis, 'path',
                           d='M%f %f v%f' % (0, 0, self.view.height),
                           class_='line')
+        lastlabel = self._x_labels[-1][0]
+        if self.x_labels_major:
+            x_labels_major = self.x_labels_major
+        elif self.x_labels_major_every:
+            x_labels_major = [self._x_labels[i][0] for i in xrange(
+                0, len(self._x_labels), self.x_labels_major_every)]
+        elif self.x_labels_major_count:
+            label_count = len(self._x_labels)
+            major_count = self.x_labels_major_count
+            if (major_count >= label_count):
+                x_labels_major = [label[0] for label in self._x_labels]
+            else:
+                x_labels_major = [self._x_labels[
+                    int(i * (label_count - 1) / (major_count - 1))][0]
+                    for i in xrange(major_count)]
+        else:
+            x_labels_major = []
         for label, position in self._x_labels:
-            major = is_major(position)
+            major = label in x_labels_major
+            if not (self.show_minor_x_labels or major):
+                continue
             guides = self.svg.node(axis, class_='guides')
             x = self.view.x(position)
             y = self.view.height + 5
             if draw_axes:
+                last_guide = (self._y_2nd_labels and label == lastlabel)
                 self.svg.node(
                     guides, 'path',
                     d='M%f %f v%f' % (x, 0, self.view.height),
                     class_='%s%sline' % (
                         'major ' if major else '',
-                        'guide ' if position != 0 else ''))
+                        'guide ' if position != 0 and not last_guide else ''))
             y += .5 * self.label_font_size + 5
             text = self.svg.node(
                 guides, 'text',
@@ -154,6 +177,28 @@ class Graph(BaseGraph):
                 text.attrib['transform'] = "rotate(%d %f %f)" % (
                     self.x_label_rotation, x, y)
 
+        if self._x_2nd_labels:
+            secondary_ax = self.svg.node(
+                self.nodes['plot'], class_="axis x x2")
+            for label, position in self._x_2nd_labels:
+                major = label in x_labels_major
+                if not (self.show_minor_x_labels or major):
+                    continue
+                # it is needed, to have the same structure as primary axis
+                guides = self.svg.node(secondary_ax, class_='guides')
+                x = self.view.x(position)
+                y = -5
+                text = self.svg.node(
+                    guides, 'text',
+                    x=x,
+                    y=y,
+                    class_='major' if major else ''
+                )
+                text.text = label
+                if self.x_label_rotation:
+                    text.attrib['transform'] = "rotate(%d %f %f)" % (
+                        -self.x_label_rotation, x, y)
+
     def _y_axis(self, draw_axes=True):
         """Make the y axis: labels and guides"""
         if not self._y_labels:
@@ -174,6 +219,8 @@ class Graph(BaseGraph):
             ))
             x = -5
             y = self.view.y(position)
+            if not y:
+                continue
             if draw_axes:
                 self.svg.node(
                     guides, 'path',
@@ -192,6 +239,26 @@ class Graph(BaseGraph):
                 text.attrib['transform'] = "rotate(%d %f %f)" % (
                     self.y_label_rotation, x, y)
 
+        if self._y_2nd_labels:
+            secondary_ax = self.svg.node(
+                self.nodes['plot'], class_="axis y2")
+            for label, position in self._y_2nd_labels:
+                major = is_major(position)
+                # it is needed, to have the same structure as primary axis
+                guides = self.svg.node(secondary_ax, class_='guides')
+                x = self.view.width + 5
+                y = self.view.y(position)
+                text = self.svg.node(
+                    guides, 'text',
+                    x=x,
+                    y=y + .35 * self.label_font_size,
+                    class_='major' if major else ''
+                )
+                text.text = label
+                if self.y_label_rotation:
+                    text.attrib['transform'] = "rotate(%d %f %f)" % (
+                        self.y_label_rotation, x, y)
+
     def _legend(self):
         """Make the legend box"""
         if not self.show_legend:
@@ -201,7 +268,7 @@ class Graph(BaseGraph):
             x = self.margin.left + 10
             y = (self.margin.top + self.view.height +
                  self._x_labels_height + 10)
-            cols = ceil(sqrt(self._order))
+            cols = ceil(sqrt(self._order)) or 1
 
             if not truncation:
                 available_space = self.view.width / cols - (
@@ -209,7 +276,7 @@ class Graph(BaseGraph):
                 truncation = reverse_text_len(
                     available_space, self.legend_font_size)
         else:
-            x = self.margin.left + self.view.width + 10
+            x = 10
             y = self.margin.top + 10
             cols = 1
             if not truncation:
@@ -221,13 +288,44 @@ class Graph(BaseGraph):
 
         h = max(self.legend_box_size, self.legend_font_size)
         x_step = self.view.width / cols
-        for i, title in enumerate(self._legends):
+        if self.legend_at_bottom:
+            # if legends at the bottom, we dont split the windows
+            # gen structure - (i, (j, (l, tf)))
+            # i - global serie number - used for coloring and identification
+            # j - position within current legend box
+            # l - label
+            # tf - whether it is secondary label
+            gen = enumerate(enumerate(chain(
+                zip(self._legends, repeat(False)),
+                zip(self._secondary_legends, repeat(True)))))
+            secondary_legends = legends  # svg node is the same
+        else:
+            gen = enumerate(chain(
+                enumerate(zip(self._legends, repeat(False))),
+                enumerate(zip(self._secondary_legends, repeat(True)))))
+
+            # draw secondary axis on right
+            x = self.margin.left + self.view.width + 10
+            if self._y_2nd_labels:
+                h, w = get_texts_box(
+                    cut(self._y_2nd_labels), self.label_font_size)
+                x += 10 + max(w * cos(rad(self.y_label_rotation)), h)
+
+            y = self.margin.top + 10
+
+            secondary_legends = self.svg.node(
+                self.nodes['graph'], class_='legends',
+                transform='translate(%d, %d)' % (x, y))
+
+        for (global_serie_number, (i, (title, is_secondary))) in gen:
+
             col = i % cols
             row = i // cols
 
             legend = self.svg.node(
-                legends, class_='legend reactive activate-serie',
-                id="activate-serie-%d" % i)
+                secondary_legends if is_secondary else legends,
+                class_='legend reactive activate-serie',
+                id="activate-serie-%d" % global_serie_number)
             self.svg.node(
                 legend, 'rect',
                 x=col * x_step,
@@ -237,7 +335,7 @@ class Graph(BaseGraph):
                 ) / 2,
                 width=self.legend_box_size,
                 height=self.legend_box_size,
-                class_="color-%d reactive" % (i % 16)
+                class_="color-%d reactive" % (global_serie_number % 16)
             )
             truncated = truncate(title, truncation)
             # Serious magical numbers here
@@ -254,10 +352,13 @@ class Graph(BaseGraph):
     def _title(self):
         """Make the title"""
         if self.title:
+            title_node = self.svg.node(
+                self.nodes['graph'],
+                class_="titles")
             for i, title_line in enumerate(self.title, 1):
                 self.svg.node(
-                    self.nodes['graph'], 'text', class_='title',
-                    x=self.margin.left + self.view.width / 2,
+                    title_node, 'text', class_='title',
+                    x=self.width / 2,
                     y=i * (self.title_font_size + 10)
                 ).text = title_line
 
@@ -327,9 +428,36 @@ class Graph(BaseGraph):
         return self._format(values[i][1])
 
     def _points(self, x_pos):
-        for serie in self.series:
+        for serie in self.all_series:
             serie.points = [
                 (x_pos[i], v)
                 for i, v in enumerate(serie.values)]
-            if self.interpolate:
+            if serie.points and self.interpolate:
                 serie.interpolated = self._interpolate(serie.values, x_pos)
+            else:
+                serie.interpolated = []
+
+    def _compute_secondary(self):
+        # secondary y axis support
+        if self.secondary_series and self._y_labels:
+            y_pos = zip(*self._y_labels)[1]
+            if self.include_x_axis:
+                ymin = min(self._secondary_min, 0)
+                ymax = max(self._secondary_max, 0)
+            else:
+                ymin = self._secondary_min
+                ymax = self._secondary_max
+            steps = len(y_pos)
+            left_range = abs(y_pos[-1] - y_pos[0])
+            right_range = abs(ymax - ymin)
+            scale = right_range / (steps - 1)
+            self._y_2nd_labels = [(self._format(ymin + i * scale), pos)
+                                  for i, pos in enumerate(y_pos)]
+
+            min_2nd = float(self._y_2nd_labels[0][0])
+            self._scale = left_range / right_range
+            self._scale_diff = y_pos[0]
+            self._scale_min_2nd = min_2nd
+
+    def _post_compute(self):
+        pass
