@@ -2,7 +2,7 @@
 # This file is part of pygal
 #
 # A python svg graph plotting library
-# Copyright © 2012 Kozea
+# Copyright © 2012-2013 Kozea
 #
 # This library is free software: you can redistribute it and/or modify it under
 # the terms of the GNU Lesser General Public License as published by the Free
@@ -34,13 +34,22 @@ class Line(Graph):
 
     @cached_property
     def _values(self):
-        return  [
+        return [
             val[1]
             for serie in self.series
             for val in (serie.interpolated
                         if self.interpolate else serie.points)
             if val[1] is not None and (not self.logarithmic or val[1] > 0)]
 
+    @cached_property
+    def _secondary_values(self):
+        return [
+            val[1]
+            for serie in self.secondary_series
+            for val in (serie.interpolated
+                        if self.interpolate else serie.points)
+            if val[1] is not None and (not self.logarithmic or val[1] > 0)]
+
     def _fill(self, values):
         """Add extra values to fill the line"""
         zero = self.view.y(min(max(self.zero, self._box.ymin), self._box.ymax))
@@ -48,9 +57,15 @@ class Line(Graph):
                 values +
                 [(values[-1][0], zero)])
 
-    def line(self, serie_node, serie):
+    def line(self, serie_node, serie, rescale=False):
         """Draw the line serie"""
-        view_values = map(self.view, serie.points)
+        if rescale and self.secondary_series:
+            points = [
+                (x, self._scale_diff + (y - self._scale_min_2nd) * self._scale)
+                for x, y in serie.points]
+        else:
+            points = serie.points
+        view_values = list(map(self.view, points))
         if self.show_dots:
             for i, (x, y) in enumerate(view_values):
                 if None in (x, y):
@@ -69,9 +84,10 @@ class Line(Graph):
                     self.svg.node(serie_node['overlay'], class_="dots"),
                     metadata)
                 val = self._get_value(serie.points, i)
-                self.svg.node(dots, 'circle', cx=x, cy=y, r=2.5,
+                self.svg.node(dots, 'circle', cx=x, cy=y, r=self.dots_size,
                               class_='dot reactive tooltip-trigger')
-                self._tooltip_data(dots, val, x, y)
+                self._tooltip_data(
+                    dots, val, x, y)
                 self._static_value(
                     serie_node, val,
                     x + self.value_font_size,
@@ -79,7 +95,7 @@ class Line(Graph):
 
         if self.stroke:
             if self.interpolate:
-                view_values = map(self.view, serie.interpolated)
+                view_values = list(map(self.view, serie.interpolated))
             if self.fill:
                 view_values = self._fill(view_values)
             self.svg.line(
@@ -87,13 +103,20 @@ class Line(Graph):
                 class_='line reactive' + (' nofill' if not self.fill else ''))
 
     def _compute(self):
+        # X Labels
         x_pos = [
             x / (self._len - 1) for x in range(self._len)
         ] if self._len != 1 else [.5]  # Center if only one value
 
         self._points(x_pos)
 
+        if self.x_labels:
+            self._x_labels = list(zip(self.x_labels, x_pos))
+        else:
+            self._x_labels = None
+
         if self.include_x_axis:
+        # Y Label
             self._box.ymin = min(self._min, 0)
             self._box.ymax = max(self._max, 0)
         else:
@@ -104,9 +127,10 @@ class Line(Graph):
             self._box.ymin, self._box.ymax, self.logarithmic, self.order_min
         ) if not self.y_labels else map(float, self.y_labels)
 
-        self._x_labels = self.x_labels and zip(self.x_labels, x_pos)
-        self._y_labels = zip(map(self._format, y_pos), y_pos)
+        self._y_labels = list(zip(map(self._format, y_pos), y_pos))
 
     def _plot(self):
         for index, serie in enumerate(self.series):
             self.line(self._serie(index), serie)
+        for index, serie in enumerate(self.secondary_series, len(self.series)):
+            self.line(self._serie(index), serie, True)
