@@ -2,7 +2,7 @@
 # This file is part of pygal
 #
 # A python svg graph plotting library
-# Copyright © 2012 Kozea
+# Copyright © 2012-2013 Kozea
 #
 # This library is free software: you can redistribute it and/or modify it under
 # the terms of the GNU Lesser General Public License as published by the Free
@@ -72,19 +72,40 @@ class Radar(Line):
         format_ = lambda x: '%f %f' % x
         center = self.view((0, 0))
         r = self._rmax
+        if self.x_labels_major:
+            x_labels_major = self.x_labels_major
+        elif self.x_labels_major_every:
+            x_labels_major = [self._x_labels[i][0] for i in xrange(
+                0, len(self._x_labels), self.x_labels_major_every)]
+        elif self.x_labels_major_count:
+            label_count = len(self._x_labels)
+            major_count = self.x_labels_major_count
+            if (major_count >= label_count):
+                x_labels_major = [label[0] for label in self._x_labels]
+            else:
+                x_labels_major = [self._x_labels[
+                    int(i * label_count / major_count)][0]
+                    for i in xrange(major_count)]
+        else:
+            x_labels_major = []
+
         for label, theta in self._x_labels:
+            major = label in x_labels_major
+            if not (self.show_minor_x_labels or major):
+                continue
             guides = self.svg.node(axis, class_='guides')
             end = self.view((r, theta))
             self.svg.node(
                 guides, 'path',
                 d='M%s L%s' % (format_(center), format_(end)),
-                class_='line')
+                class_='%sline' % ('major ' if major else ''))
             r_txt = (1 - self._box.__class__.margin) * self._box.ymax
             pos_text = self.view((r_txt, theta))
             text = self.svg.node(
                 guides, 'text',
                 x=pos_text[0],
-                y=pos_text[1])
+                y=pos_text[1],
+                class_='major' if major else '')
             text.text = label
             angle = - theta + pi / 2
             if cos(angle) < 0:
@@ -117,7 +138,7 @@ class Radar(Line):
     def _compute(self):
         delta = 2 * pi / self._len if self._len else 0
         x_pos = [.5 * pi + i * delta for i in range(self._len + 1)]
-        for serie in self.series:
+        for serie in self.all_series:
             serie.points = [
                 (v, x_pos[i])
                 for i, v in enumerate(serie.values)]
@@ -145,8 +166,8 @@ class Radar(Line):
             max_scale=8
         ) if not self.y_labels else map(int, self.y_labels)
 
-        self._x_labels = self.x_labels and zip(self.x_labels, x_pos)
-        self._y_labels = zip(map(self._format, y_pos), y_pos)
+        self._x_labels = self.x_labels and list(zip(self.x_labels, x_pos))
+        self._y_labels = list(zip(map(self._format, y_pos), y_pos))
 
         self.x_pos = x_pos
         self._self_close = True
