@@ -2,7 +2,7 @@
 # This file is part of pygal
 #
 # A python svg graph plotting library
-# Copyright © 2012 Kozea
+# Copyright © 2012-2013 Kozea
 #
 # This library is free software: you can redistribute it and/or modify it under
 # the terms of the GNU Lesser General Public License as published by the Free
@@ -23,7 +23,7 @@ Stacked Bar chart
 
 from __future__ import division
 from pygal.graph.bar import Bar
-from pygal.util import compute_scale
+from pygal.util import compute_scale, swap, ident
 from pygal.adapters import none_to_zero
 
 
@@ -32,8 +32,9 @@ class StackedBar(Bar):
 
     _adapters = [none_to_zero]
 
-    def _get_separated_values(self):
-        transposed = zip(*[serie.values for serie in self.series])
+    def _get_separated_values(self, secondary=False):
+        series = self.secondary_series if secondary else self.series
+        transposed = zip(*[serie.values for serie in series])
         positive_vals = [sum([
             val for val in vals
             if val is not None and val >= self.zero])
@@ -54,8 +55,8 @@ class StackedBar(Bar):
         self._compute_box(positive_vals, negative_vals)
 
         if self.logarithmic:
-            positive_vals = filter(lambda x: x > 0, positive_vals)
-            negative_vals = filter(lambda x: x > 0, negative_vals)
+            positive_vals = list(filter(lambda x: x > 0, positive_vals))
+            negative_vals = list(filter(lambda x: x > 0, negative_vals))
 
         positive_vals = positive_vals or [self.zero]
         negative_vals = negative_vals or [self.zero]
@@ -70,20 +71,57 @@ class StackedBar(Bar):
         ) if not self.y_labels else map(float, self.y_labels)
         self._x_ranges = zip(x_pos, x_pos[1:])
 
-        self._x_labels = self.x_labels and zip(self.x_labels, [
-            sum(x_range) / 2 for x_range in self._x_ranges])
-        self._y_labels = zip(map(self._format, y_pos), y_pos)
+        self._x_labels = self.x_labels and list(zip(self.x_labels, [
+            sum(x_range) / 2 for x_range in self._x_ranges]))
+        self._y_labels = list(zip(map(self._format, y_pos), y_pos))
 
         self.negative_cumulation = [0] * self._len
         self.positive_cumulation = [0] * self._len
 
-    def _bar(self, parent, x, y, index, i, zero, shift=True):
-        cumulation = (self.negative_cumulation if y < self.zero else
-                      self.positive_cumulation)
+        if self.secondary_series:
+            positive_vals, negative_vals = self._get_separated_values(True)
+            self.secondary_negative_cumulation = [0] * self._len
+            self.secondary_positive_cumulation = [0] * self._len
+
+            # In case of pyramids
+            sum_ = lambda x: sum(x) if isinstance(x, tuple) else x
+            self._secondary_min = negative_vals and min(
+                sum_(min(negative_vals)), self.zero)
+            self._secondary_max = positive_vals and max(
+                sum_(max(positive_vals)), self.zero)
+
+    def _bar(self, parent, x, y, index, i, zero, shift=False, secondary=False):
+        if secondary:
+            cumulation = (self.secondary_negative_cumulation
+                          if y < self.zero else
+                          self.secondary_positive_cumulation)
+        else:
+            cumulation = (self.negative_cumulation
+                          if y < self.zero else
+                          self.positive_cumulation)
         zero = cumulation[i]
         cumulation[i] = zero + y
         if zero == 0:
             zero = self.zero
             y -= self.zero
-        return super(StackedBar, self)._bar(
-            parent, x, zero + y, index, i, zero, False)
+        y += zero
+
+        width = (self.view.x(1) - self.view.x(0)) / self._len
+        x, y = self.view((x, y))
+        series_margin = width * self._series_margin
+        x += series_margin
+        width -= 2 * series_margin
+        if self.secondary_series:
+            width /= 2
+            x += int(secondary) * width
+            serie_margin = width * self._serie_margin
+            x += serie_margin
+            width -= 2 * serie_margin
+        height = self.view.y(zero) - y
+        r = self.rounded_bars * 1 if self.rounded_bars else 0
+        self.svg.transposable_node(
+            parent, 'rect',
+            x=x, y=y, rx=r, ry=r, width=width, height=height,
+            class_='rect reactive tooltip-trigger')
+        transpose = swap if self.horizontal else ident
+        return transpose((x + width / 2, y + height / 2))
