@@ -2,7 +2,7 @@
 # This file is part of pygal
 #
 # A python svg graph plotting library
-# Copyright © 2012 Kozea
+# Copyright © 2012-2013 Kozea
 #
 # This library is free software: you can redistribute it and/or modify it under
 # the terms of the GNU Lesser General Public License as published by the Free
@@ -39,8 +39,10 @@ def interpolation(x, y, kind):
     if len(y) < len(x):
         x = x[:len(y)]
 
-    x, y = zip(*filter(lambda t: None not in t, zip(x, y)))
-
+    pack = list(zip(*filter(lambda t: None not in t, zip(x, y))))
+    if len(pack) == 0:
+        return ident
+    x, y = pack
     if len(x) < 2:
         return ident
     if isinstance(kind, int):
