@@ -2,7 +2,7 @@
 # This file is part of pygal
 #
 # A python svg graph plotting library
-# Copyright © 2012 Kozea
+# Copyright © 2012-2013 Kozea
 #
 # This library is free software: you can redistribute it and/or modify it under
 # the terms of the GNU Lesser General Public License as published by the Free
@@ -17,6 +17,7 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with pygal. If not, see <http://www.gnu.org/licenses/>.
 from pygal import Line, Dot, Pie, Radar, Config
+from pygal._compat import u
 from pygal.test.utils import texts
 from pygal.test import pytest_generate_tests, make_data
 
@@ -152,11 +153,20 @@ def test_interpolation(Chart):
     assert len(q(".legend")) == 2
 
 
+def test_no_data_interpolation(Chart):
+    chart = Chart(interpolate='cubic')
+    q = chart.render_pyquery()
+    assert q(".text-overlay text").text() == "No data"
+
+
+def test_no_data_with_empty_serie_interpolation(Chart):
+    chart = Chart(interpolate='cubic')
+    chart.add('Serie', [])
+    q = chart.render_pyquery()
+    assert q(".text-overlay text").text() == "No data"
+
+
 def test_logarithmic_bad_interpolation():
-    try:
-        import scipy
-    except ImportError:
-        return
     line = Line(logarithmic=True, interpolate='cubic')
     line.add('_', [.001, .00000001, 1])
     q = line.render_pyquery()
@@ -181,12 +191,12 @@ def test_human_readable():
     line = Line()
     line.add('_', [10 ** 4, 10 ** 5, 23 * 10 ** 4])
     q = line.render_pyquery()
-    assert q(".axis.y text").map(texts) == map(
-        str, map(float, range(20000, 240000, 20000)))
+    assert q(".axis.y text").map(texts) == list(map(
+        str, map(float, range(20000, 240000, 20000))))
     line.human_readable = True
     q = line.render_pyquery()
-    assert q(".axis.y text").map(texts) == map(
-        lambda x: '%dk' % x, range(20, 240, 20))
+    assert q(".axis.y text").map(texts) == list(map(
+        lambda x: '%dk' % x, range(20, 240, 20)))
 
 
 def test_show_legend():
@@ -213,6 +223,6 @@ def test_no_data():
     line = Line()
     q = line.render_pyquery()
     assert q(".text-overlay text").text() == "No data"
-    line.no_data_text = u"þæ®þæ€€&ĳ¿’€"
+    line.no_data_text = u("þæ®þæ€€&ĳ¿’€")
     q = line.render_pyquery()
-    assert q(".text-overlay text").text() == u"þæ®þæ€€&ĳ¿’€"
+    assert q(".text-overlay text").text() == u("þæ®þæ€€&ĳ¿’€")
