@@ -2,7 +2,7 @@
 # This file is part of pygal
 #
 # A python svg graph plotting library
-# Copyright © 2012 Kozea
+# Copyright © 2012-2013 Kozea
 #
 # This library is free software: you can redistribute it and/or modify it under
 # the terms of the GNU Lesser General Public License as published by the Free
@@ -19,7 +19,9 @@
 import os
 import pygal
 import uuid
+import sys
 from pygal.util import cut
+from pygal._compat import u
 from pygal.test import pytest_generate_tests, make_data
 
 
@@ -66,7 +68,7 @@ def test_metadata(Chart):
     chart = Chart()
     v = range(7)
     if Chart == pygal.XY:
-        v = map(lambda x: (x, x + 1), v)
+        v = list(map(lambda x: (x, x + 1), v))
 
     chart.add('Serie with metadata', [
         v[0],
@@ -86,7 +88,12 @@ def test_metadata(Chart):
             'Five', 'http://7.example.com/', 'Seven'):
         assert md in cut(q('desc'), 'text')
 
-    assert len(v) == len(q('.tooltip-trigger').siblings('.value'))
+    if Chart == pygal.Pie:
+        # Slices with value 0 are not rendered
+        assert len(v) - 1 == len(q('.tooltip-trigger').siblings('.value'))
+    elif Chart != pygal.Worldmap:
+        # Tooltip are not working on worldmap
+        assert len(v) == len(q('.tooltip-trigger').siblings('.value'))
 
 
 def test_empty_lists(Chart):
@@ -137,24 +144,33 @@ def test_iterable_types(Chart):
 
 
 def test_values_by_dict(Chart):
-    chart = Chart()
-    chart.add('A', {'red': 10, 'green': 12, 'blue': 14})
-    chart.add('B', {'green': 11, 'red': 7})
-    chart.add('C', {'blue': 7})
-    chart.add('D', {})
-    chart.add('E', {'blue': 2, 'red': 13})
-    chart.x_labels = ('red', 'green', 'blue')
-    chart1 = chart.render()
+    chart1 = Chart()
+    chart2 = Chart()
 
-    chart = Chart()
-    chart.add('A', [10, 12, 14])
-    chart.add('B', [7, 11])
-    chart.add('C', [None, None, 7])
-    chart.add('D', [])
-    chart.add('E', [13, None, 2])
-    chart.x_labels = ('red', 'green', 'blue')
-    chart2 = chart.render()
-    assert chart1 == chart2
+    if Chart != pygal.Worldmap:
+        chart1.add('A', {'red': 10, 'green': 12, 'blue': 14})
+        chart1.add('B', {'green': 11, 'red': 7})
+        chart1.add('C', {'blue': 7})
+        chart1.add('D', {})
+        chart1.add('E', {'blue': 2, 'red': 13})
+        chart1.x_labels = ('red', 'green', 'blue')
+
+        chart2.add('A', [10, 12, 14])
+        chart2.add('B', [7, 11])
+        chart2.add('C', [None, None, 7])
+        chart2.add('D', [])
+        chart2.add('E', [13, None, 2])
+        chart2.x_labels = ('red', 'green', 'blue')
+    else:
+        chart1.add('A', {'fr': 10, 'us': 12, 'jp': 14})
+        chart1.add('B', {'cn': 99})
+        chart1.add('C', {})
+
+        chart2.add('A', [('fr', 10), ('us', 12), ('jp', 14)])
+        chart2.add('B', [('cn', 99)])
+        chart2.add('C', [None, (None, None)])
+
+    assert chart1.render() == chart2.render()
 
 
 def test_no_data_with_no_values(Chart):
@@ -198,3 +214,67 @@ def test_no_data_with_lists_of_nones(Chart):
     chart.add('Serie2', [None, None, None])
     q = chart.render_pyquery()
     assert q(".text-overlay text").text() == "No data"
+
+
+def test_unicode_labels_decode(Chart):
+    chart = Chart()
+    chart.add(u('Série1'), [{
+        'value': 1,
+        'xlink': 'http://1/',
+        'label': u('{\}Â°ĳæð©&×&<—×€¿_…\{_…')
+    }, {
+        'value': 2,
+        'xlink': {
+            'href': 'http://6.example.com/'
+        },
+        'label': u('æÂ°€≠|€æÂ°€əæ')
+    }, {
+        'value': 3,
+        'label': 'unicode <3'
+    }])
+    chart.x_labels = [u('&œ'), u('¿?'), u('††††††††'), 'unicode <3']
+    q = chart.render_pyquery()
+
+
+def test_unicode_labels_python2(Chart):
+    if sys.version_info[0] == 3:
+        return
+    chart = Chart()
+    chart.add(u('Série1'), [{
+        'value': 1,
+        'xlink': 'http://1/',
+        'label': eval("u'{\}Â°ĳæð©&×&<—×€¿_…\{_…'")
+    }, {
+        'value': 2,
+        'xlink': {
+            'href': 'http://6.example.com/'
+        },
+        'label': eval("u'æÂ°€≠|€æÂ°€əæ'")
+    }, {
+        'value': 3,
+        'label': eval("'unicode <3'")
+    }])
+    chart.x_labels = eval("[u'&œ', u'¿?', u'††††††††', 'unicode <3']")
+    q = chart.render_pyquery()
+
+
+def test_unicode_labels_python3(Chart):
+    if sys.version_info[0] == 2:
+        return
+    chart = Chart()
+    chart.add(u('Série1'), [{
+        'value': 1,
+        'xlink': 'http://1/',
+        'label': eval("'{\}Â°ĳæð©&×&<—×€¿_…\{_…'")
+    }, {
+        'value': 2,
+        'xlink': {
+            'href': 'http://6.example.com/'
+        },
+        'label': eval("'æÂ°€≠|€æÂ°€əæ'")
+    }, {
+        'value': 3,
+        'label': eval("b'unicode <3'")
+    }])
+    chart.x_labels = eval("['&œ', '¿?', '††††††††', 'unicode <3']")
+    q = chart.render_pyquery()
