@@ -2,7 +2,7 @@
 # This file is part of pygal
 #
 # A python svg graph plotting library
-# Copyright © 2012 Kozea
+# Copyright © 2012-2013 Kozea
 #
 # This library is free software: you can redistribute it and/or modify it under
 # the terms of the GNU Lesser General Public License as published by the Free
@@ -21,12 +21,14 @@ Various utils
 
 """
 from __future__ import division
+from pygal._compat import to_str, u
 import re
 from decimal import Decimal
 from math import floor, pi, log, log10, ceil
 from itertools import cycle
+from functools import reduce
 from pygal.adapters import not_zero, positive
-ORDERS = u"yzafpnµm kMGTPEZY"
+ORDERS = u("yzafpnµm kMGTPEZY")
 
 
 def float_format(number):
@@ -78,7 +80,7 @@ def cut(list_, index=0):
         cut_ = lambda x: x[index]
     else:
         cut_ = lambda x: getattr(x, index)
-    return map(cut_, list_)
+    return list(map(cut_, list_))
 
 
 def rad(degrees):
@@ -208,11 +210,12 @@ def decorate(svg, node, metadata):
         if not isinstance(xlink, dict):
             xlink = {'href': xlink, 'target': '_blank'}
         node = svg.node(node, 'a', **xlink)
+
     for key, value in metadata.items():
         if key == 'xlink' and isinstance(value, dict):
             value = value.get('href', value)
         if value:
-            svg.node(node, 'desc', class_=key).text = str(value)
+            svg.node(node, 'desc', class_=key).text = to_str(value)
     return node
 
 
@@ -221,14 +224,14 @@ def cycle_fill(short_list, max_len):
     short_list = list(short_list)
     list_cycle = cycle(short_list)
     while len(short_list) < max_len:
-        short_list.append(list_cycle.next())
+        short_list.append(next(list_cycle))
     return short_list
 
 
 def truncate(string, index):
     """Truncate a string at index and add ..."""
     if len(string) > index and index > 0:
-        string = string[:index - 1] + u'…'
+        string = string[:index - 1] + u('…')
     return string
 
 
@@ -294,8 +297,19 @@ from pygal.serie import Serie
 
 def prepare_values(raw, config, cls):
     """Prepare the values to start with sane values"""
+    from pygal.graph.datey import DateY
+    from pygal.graph.worldmap import Worldmap
+    if config.x_labels is None and hasattr(cls, 'x_labels'):
+        config.x_labels = cls.x_labels
+    if config.zero == 0 and issubclass(cls, Worldmap):
+        config.zero = 1
+
+    for key in ('x_labels', 'y_labels'):
+        if getattr(config, key):
+            setattr(config, key, list(getattr(config, key)))
     if not raw:
         return
+
     adapters = list(cls._adapters) or [lambda x:x]
     if config.logarithmic:
         for fun in not_zero, positive:
@@ -304,6 +318,12 @@ def prepare_values(raw, config, cls):
         adapters = adapters + [positive, not_zero]
     adapter = reduce(compose, adapters) if not config.strict else ident
     series = []
+
+    raw = [(
+        title,
+        list(raw_values) if not isinstance(raw_values, dict) else raw_values
+    ) for title, raw_values in raw]
+
     width = max([len(values) for _, values in raw] +
                 [len(config.x_labels or [])])
 
@@ -311,13 +331,14 @@ def prepare_values(raw, config, cls):
         metadata = {}
         values = []
         if isinstance(raw_values, dict):
-            value_list = [None] * width
-            for k, v in raw_values.items():
-                if k in config.x_labels:
-                    value_list[config.x_labels.index(k)] = v
-            raw_values = value_list
-        else:
-            raw_values = list(raw_values)
+            if issubclass(cls, Worldmap):
+                raw_values = list(raw_values.items())
+            else:
+                value_list = [None] * width
+                for k, v in raw_values.items():
+                    if k in config.x_labels:
+                        value_list[config.x_labels.index(k)] = v
+                raw_values = value_list
 
         for index, raw_value in enumerate(
                 raw_values + (
@@ -329,10 +350,15 @@ def prepare_values(raw, config, cls):
             else:
                 value = raw_value
 
-            if cls.__name__ == 'XY':
-                if not hasattr(value, '__iter__'):
+            if cls._dual:
+                if value is None:
+                    value = (None, None)
+                elif not hasattr(value, '__iter__'):
                     value = (value, config.zero)
-                value = map(adapter, value)
+                if issubclass(cls, DateY) or issubclass(cls, Worldmap):
+                    value = (adapter(value[0]), value[1])
+                else:
+                    value = list(map(adapter, value))
             else:
                 value = adapter(value)
 
