@@ -2,7 +2,7 @@
 # This file is part of pygal
 #
 # A python svg graph plotting library
-# Copyright © 2012 Kozea
+# Copyright © 2012-2013 Kozea
 #
 # This library is free software: you can redistribute it and/or modify it under
 # the terms of the GNU Lesser General Public License as published by the Free
@@ -293,8 +293,8 @@ class LogView(View):
         self.width = width
         self.height = height
         self.box = box
-        self.log10_ymax = log10(self.box.ymax)
-        self.log10_ymin = log10(self.box.ymin)
+        self.log10_ymax = log10(self.box.ymax) if self.box.ymax > 0 else 0
+        self.log10_ymin = log10(self.box.ymin) if self.box.ymin > 0 else 0
         self.box.fix(False)
 
     # pylint: enable-msg=W0231
